@@ -13,6 +13,7 @@ our @EXPORT_OK = qw/
     filter
     is_required
     is_required_if
+    is_existing
     is_equal
     is_long_between
     is_long_at_least
@@ -26,14 +27,14 @@ our %EXPORT_TAGS = (
     'all' => \@EXPORT_OK
 );
 
-our $VERSION = '1.501';
+our $VERSION = '1.551';
 
 our %FILTERS = (
-    trim    => sub { $_[0] // return; $_[0] =~ s/^\s+//; $_[0] =~ s/\s+$//; $_[0]  },
-    strip   => sub { $_[0] // return; $_[0] =~ s/(\s){2,}/$1/g; $_[0] },
-    lc      => sub { $_[0] // return; lc $_[0] },
-    uc      => sub { $_[0] // return; uc $_[0] },
-    ucfirst => sub { $_[0] // return; ucfirst $_[0] },
+    trim    => sub { return unless defined $_[0]; $_[0] =~ s/^\s+//; $_[0] =~ s/\s+$//; $_[0]  },
+    strip   => sub { return unless defined $_[0]; $_[0] =~ s/(\s){2,}/$1/g; $_[0] },
+    lc      => sub { return unless defined $_[0]; lc $_[0] },
+    uc      => sub { return unless defined $_[0]; uc $_[0] },
+    ucfirst => sub { return unless defined $_[0]; ucfirst $_[0] },
 );
 
 sub validate {
@@ -120,7 +121,8 @@ sub _process {
             }
         }
     }
-    return $check ? undef : $value;
+    return if $check;
+    return $value;
 }
 
 sub _match {
@@ -154,7 +156,10 @@ sub filter {
 
 sub is_required {
     my $err_msg = shift || 'Required';
-    return sub { defined $_[0] && $_[0] ne '' ? undef : $err_msg  }
+    return sub {
+        return if defined $_[0] && $_[0] ne '';
+        return $err_msg;
+    };
 }
 
 sub is_required_if {
@@ -171,18 +176,26 @@ sub is_required_if {
           ? $condition->($params)
           : $condition;
         return unless $required;
-        return defined $value && $value ne '' ? undef : $err_msg;
+        return if defined $value && $value ne '';
+        return $err_msg;
     };
 }
 
+sub is_existing {
+    my $err_msg = shift || 'Must be defined';
+    return sub {
+        return if exists $_[1]->{$_[2]};
+        return $err_msg;
+    }
+}
+
 sub is_equal {
     my ( $other, $err_msg ) = @_;
     $err_msg ||= 'Invalid value';
     return sub {
-        return undef if !defined($_[0]) || $_[0] eq '';
-        return defined $_[1]->{$other} && $_[0] eq $_[1]->{$other}
-          ? undef
-          : $err_msg;
+        return if !defined($_[0]) || $_[0] eq '';
+        return if defined $_[1]->{$other} && $_[0] eq $_[1]->{$other};
+        return $err_msg;
     };
 }
 
@@ -190,10 +203,9 @@ sub is_long_between {
     my ( $min, $max, $err_msg ) = @_;
     $err_msg ||= "Must be between $min and $max symbols";
     return sub {
-        return undef if !defined($_[0]) || $_[0] eq '';
-        length( $_[0] ) >= $min && length( $_[0] ) <= $max
-          ? undef
-          : $err_msg;
+        return if !defined($_[0]) || $_[0] eq '';
+        return if length( $_[0] ) >= $min && length( $_[0] ) <= $max;
+        return $err_msg;
     };
 }
 
@@ -201,8 +213,9 @@ sub is_long_at_least {
     my ( $length, $err_msg ) = @_;
     $err_msg ||= "Must be at least $length symbols";
     return sub {
-        return undef if !defined($_[0]) || $_[0] eq '';
-        length( $_[0] ) >= $length ? undef : $err_msg;
+        return if !defined($_[0]) || $_[0] eq '';
+        return if length( $_[0] ) >= $length;
+        return $err_msg;
     };
 }
 
@@ -210,8 +223,9 @@ sub is_long_at_most {
     my ( $length, $err_msg ) = @_;
     $err_msg ||= "Must be at the most $length symbols";
     return sub {
-        return undef if !defined($_[0]) || $_[0] eq '';
-        length( $_[0] ) <= $length ? undef : $err_msg;
+        return if !defined($_[0]) || $_[0] eq '';
+        return if length( $_[0] ) <= $length;
+        return $err_msg;
     };
 }
 
@@ -219,9 +233,9 @@ sub is_a {
     my ( $class, $err_msg ) = @_;
     $err_msg ||= "Invalid value";
     return sub {
-        return undef if !defined($_[0]) || $_[0] eq '';
-        ref($_[0]) eq $class ? undef : $err_msg;
-    }
+        return if !defined( $_[0] ) || ref( $_[0] ) eq $class;
+        return $err_msg;
+    };
 }
 
 sub is_like {
@@ -229,8 +243,9 @@ sub is_like {
     $err_msg ||= "Invalid value";
     croak 'Regexp expected' unless ref($regexp) eq 'Regexp';
     return sub {
-        return undef if !defined($_[0]) || $_[0] eq '';
-        $_[0] =~ $regexp ? undef : $err_msg;
+        return if !defined($_[0]) || $_[0] eq '';
+        return if $_[0] =~ $regexp;
+        return $err_msg;
     };
 }
 
@@ -239,8 +254,9 @@ sub is_in {
     $err_msg ||= "Invalid value";
     croak 'ArrayRef expected' unless ref($arrayref) eq 'ARRAY';
     return sub {
-        return undef if !defined($_[0]) || $_[0] eq '';
-        _match( $_[0], $arrayref ) ? undef : $err_msg;
+        return if !defined($_[0]) || $_[0] eq '';
+        return if _match( $_[0], $arrayref );
+        return $err_msg;
       }
 }
 
@@ -353,14 +369,15 @@ Filter and validate user input from forms, etc.
             # custom sub validates an email address
             email => sub {
                 my ( $value, $params ) = @_;
-                Email::Valid->address($value) ? undef : 'Invalid email';
+                return if Email::Valid->address($value);
+                return 'Invalid email';
             },
 
             # custom sub to validate gender
             gender => sub {
                 my ( $value, $params ) = @_;
-                return $value eq 'M'
-                  || $value eq 'F' ? undef : 'Invalid gender';
+                return if $value eq 'M' || $value eq 'F';
+                return 'Invalid gender';
             }
 
         ]
@@ -570,7 +587,7 @@ B<Example:>
         my ( $value, $params ) = @_;
 
         if ( !defined $value or $value eq '' ) {
-            return undef;
+            return;
         }
 
         if ( length($value) < 6 ) {
@@ -586,7 +603,7 @@ B<Example:>
         }
 
         # At this point we're happy with the password
-        return undef;
+        return;
     }
 
     my $rules = {
@@ -653,9 +670,8 @@ recommended approach:
         my ( $min, $max ) = @_;
         return sub {
             my $value = shift;
-            return length($value) >= $min && length($value) <= $max
-              ? undef
-              : "Must be between $min and $max symbols";
+            return if length($value) >= $min && length($value) <= $max;
+            return "Must be between $min and $max symbols";
         };
     }
 
@@ -772,6 +788,11 @@ Second example:
         ]
     };
 
+=head2 is_existing
+
+Much like C<is_required>, but checks if the field contains any value, even an
+empty string and C<undef>.
+
 =head2 is_equal
 
     is_equal( $other_field_name, $opt_error_msg )
@@ -953,14 +974,15 @@ https://github.com/naturalist/Validate--Tiny
 
 =head1 AUTHOR
 
-    miniml (cpan: MINIMAL) - minimal@cpan.org
+    Stefan G. (cpan: MINIMAL) - minimal@cpan.org
 
 =head1 CONTRIBUTORS
 
-    Patrice Clement (cpan: MONSIEURP) - monsieurp@gentoo.org
     Viktor Turskyi (cpan: KOORCHIK) - koorchik@cpan.org
     Ivan Simonik (cpan: SIMONIKI) - simoniki@cpan.org
-    Daya Sagar Nune
+    Daya Sagar Nune (cpan: DAYANUNE) - daya.webtech@gmail.com
+    val - valkoles@gmail.com
+    Patrice Clement (cpan: MONSIEURP) - monsieurp@gentoo.org
 
 =head1 LICENCE
 
